<?php

namespace Drupal\views_add_button_group\Plugin\views_add_button;

use Drupal\Core\Plugin\PluginBase;
use Drupal\Core\Url;
use Drupal\views_add_button\ViewsAddButtonInterface;

/**
 * @ViewsAddButton(
 *   id = "views_add_button_group_content",
 *   label = @Translation("ViewsAddButtonGroup"),
 *   target_entity = "group_content"
 * )
 */
class ViewsAddButtonGroupContent extends PluginBase implements ViewsAddButtonInterface {

  /**
   * @return string
   *   A string description.
   */
  public function description()
  {
    return $this->t('Views Add Button URL Generator for Group Content entities');
  }

  public static function checkAccess($entity_type, $bundle, $context) {
    // TODO add access callback for this entity
    return TRUE;
  }

  public static function generate_url($entity_type, $bundle, $options, $context = '') {
    // We are expecting a bundle of the type group-group_[entity_type]-[entity_type_bundle]
    $c  = explode('-', $bundle);
    $plugin_id = '';
    // For entities with shorter names, it will be of the type group_type-group_entity-group_entity_bundle
    if (count($c) === 3) {
      $plugin_id = implode(':', array($c[1], $c[2]));
    }
    // For entities with a long name, i.e. group_content_type_12d187f0f3346 , extract the plugin_id
    elseif (count($c) === 1) {
      $storage_config = \Drupal::configFactory()->getEditable('group.content_type.' . $c[0]);
      $plugin_id = $storage_config->getOriginal('content_plugin');
    }
    // Create URL from the data above
    if ($context && $plugin_id) {
      $url = Url::fromRoute('entity.group_content.create_form', array('group' => $context, 'plugin_id' => $plugin_id), $options);
      return $url;
    }
  }

}